Version of download.file that verifies downloads. All
arguments are passed through to utils::download.packages
verbatim and the documentation there should be consulted for the
meaning of arguments.
download_packages(pkgs, destdir, available = NULL,
repos = getOption("repos"), contriburl = contrib.url(repos, type), method,
type = getOption("pkgType"), ..., pubkey = NULL)Character vector of packages to download
Destination directory
Set of available packages, as created by
available.packages
Character vector of base URL(s) of repositories
(passed through to available.packages.
URL(s) of the contrib sections of the repositories
Download method
character string, indicating which type of packages to install.
Additional arguments passed through to
utils::download.packages (and from there through to
download.file.
Public key used to verify the package index